pub struct EmailDocumentResponse {
pub message: String,
}Fields
message: StringTrait Implementations
Sourceimpl Clone for EmailDocumentResponse
impl Clone for EmailDocumentResponse
Sourcefn clone(&self) -> EmailDocumentResponse
fn clone(&self) -> EmailDocumentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmailDocumentResponse
impl Debug for EmailDocumentResponse
Sourceimpl<'de> Deserialize<'de> for EmailDocumentResponse
impl<'de> Deserialize<'de> for EmailDocumentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for EmailDocumentResponse
impl Display for EmailDocumentResponse
Sourceimpl JsonSchema for EmailDocumentResponse
impl JsonSchema for EmailDocumentResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EmailDocumentResponse
impl PartialEq for EmailDocumentResponse
Sourcefn eq(&self, other: &EmailDocumentResponse) -> bool
fn eq(&self, other: &EmailDocumentResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EmailDocumentResponse
impl Serialize for EmailDocumentResponse
Sourceimpl Tabled for EmailDocumentResponse
Available on crate feature tabled only.
impl Tabled for EmailDocumentResponse
Available on crate feature
tabled only.impl StructuralPartialEq for EmailDocumentResponse