pub struct EmailDocumentsResponse {
pub message: String,
}Fields
message: StringTrait Implementations
Sourceimpl Clone for EmailDocumentsResponse
impl Clone for EmailDocumentsResponse
Sourcefn clone(&self) -> EmailDocumentsResponse
fn clone(&self) -> EmailDocumentsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmailDocumentsResponse
impl Debug for EmailDocumentsResponse
Sourceimpl<'de> Deserialize<'de> for EmailDocumentsResponse
impl<'de> Deserialize<'de> for EmailDocumentsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for EmailDocumentsResponse
impl Display for EmailDocumentsResponse
Sourceimpl JsonSchema for EmailDocumentsResponse
impl JsonSchema for EmailDocumentsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EmailDocumentsResponse
impl PartialEq for EmailDocumentsResponse
Sourcefn eq(&self, other: &EmailDocumentsResponse) -> bool
fn eq(&self, other: &EmailDocumentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EmailDocumentsResponse
impl Serialize for EmailDocumentsResponse
Sourceimpl Tabled for EmailDocumentsResponse
Available on crate feature tabled only.
impl Tabled for EmailDocumentsResponse
Available on crate feature
tabled only.impl StructuralPartialEq for EmailDocumentsResponse