pub struct ProcessedMail {
pub id: i64,
pub owner: Option<i64>,
pub rule: i64,
pub folder: String,
pub uid: String,
pub subject: String,
pub received: DateTime<Utc>,
pub processed: DateTime<Utc>,
pub status: String,
pub error: Option<String>,
}Fields
id: i64owner: Option<i64>rule: i64folder: Stringuid: Stringsubject: Stringreceived: DateTime<Utc>processed: DateTime<Utc>status: Stringerror: Option<String>Trait Implementations
Sourceimpl Clone for ProcessedMail
impl Clone for ProcessedMail
Sourcefn clone(&self) -> ProcessedMail
fn clone(&self) -> ProcessedMail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessedMail
impl Debug for ProcessedMail
Sourceimpl<'de> Deserialize<'de> for ProcessedMail
impl<'de> Deserialize<'de> for ProcessedMail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ProcessedMail
impl Display for ProcessedMail
Sourceimpl JsonSchema for ProcessedMail
impl JsonSchema for ProcessedMail
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessedMail
impl PartialEq for ProcessedMail
Sourcefn eq(&self, other: &ProcessedMail) -> bool
fn eq(&self, other: &ProcessedMail) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessedMail
impl Serialize for ProcessedMail
Sourceimpl Tabled for ProcessedMail
Available on crate feature tabled only.
impl Tabled for ProcessedMail
Available on crate feature
tabled only.impl StructuralPartialEq for ProcessedMail