pub struct ProcessedMailRequest {
pub owner: Option<i64>,
}Fields
owner: Option<i64>Trait Implementations
Sourceimpl Clone for ProcessedMailRequest
impl Clone for ProcessedMailRequest
Sourcefn clone(&self) -> ProcessedMailRequest
fn clone(&self) -> ProcessedMailRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessedMailRequest
impl Debug for ProcessedMailRequest
Sourceimpl<'de> Deserialize<'de> for ProcessedMailRequest
impl<'de> Deserialize<'de> for ProcessedMailRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ProcessedMailRequest
impl Display for ProcessedMailRequest
Sourceimpl JsonSchema for ProcessedMailRequest
impl JsonSchema for ProcessedMailRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessedMailRequest
impl PartialEq for ProcessedMailRequest
Sourcefn eq(&self, other: &ProcessedMailRequest) -> bool
fn eq(&self, other: &ProcessedMailRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessedMailRequest
impl Serialize for ProcessedMailRequest
Sourceimpl Tabled for ProcessedMailRequest
Available on crate feature tabled only.
impl Tabled for ProcessedMailRequest
Available on crate feature
tabled only.impl StructuralPartialEq for ProcessedMailRequest